PCB Environment: dsn::Net Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Net Struct Reference

## Public Member Functions
std::string | str () const

## Data Fields
std::string | name
std::string | klass
int | index {-1}
std::set< std::string > | pins
double | clearance {0.0}
double | via_diameter {0.0}
double | width {0.0}
std::vector< Segment > | segments
std::vector< Via > | vias
std::vector< Connection > | connections

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp